==> aliyun-java-sdk-green-3.5.1-sources.jar: com/aliyuncs/green/model/v20170823/DescribeOssStockStatusResponse.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.green.model.v20170823;

import java.util.List;
import com.aliyuncs.AcsResponse;
import com.aliyuncs.green.transform.v20170823.DescribeOssStockStatusResponseUnmarshaller;
import com.aliyuncs.transform.UnmarshallerContext;

/**
 * @author auto create
 * @version 
 */
public class DescribeOssStockStatusResponse extends AcsResponse {

	private String requestId;

	private Integer stockStatus;

	private String finishedTime;

	private Integer imageTotalCount;

	private Integer imagePornCount;

	private Integer imageTerrorismCount;

	private Integer videoTotalCount;

	private Integer videoPornCount;

	private Integer videoTerrorismCount;

	private List<Bucket> bucketList;

	private List<String> sceneList;

	private List<String> resouceTypeList;

	public String getRequestId() {
		return this.requestId;
	}

	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	public Integer getStockStatus() {
		return this.stockStatus;
	}

	public void setStockStatus(Integer stockStatus) {
		this.stockStatus = stockStatus;
	}

	public String getFinishedTime() {
		return this.finishedTime;
	}

	public void setFinishedTime(String finishedTime) {
		this.finishedTime = finishedTime;
	}

	public Integer getImageTotalCount() {
		return this.imageTotalCount;
	}

	public void setImageTotalCount(Integer imageTotalCount) {
		this.imageTotalCount = imageTotalCount;
	}

	public Integer getImagePornCount() {
		return this.imagePornCount;
	}

	public void setImagePornCount(Integer imagePornCount) {
		this.imagePornCount = imagePornCount;
	}

	public Integer getImageTerrorismCount() {
		return this.imageTerrorismCount;
	}

	public void setImageTerrorismCount(Integer imageTerrorismCount) {
		this.imageTerrorismCount = imageTerrorismCount;
	}

	public Integer getVideoTotalCount() {
		return this.videoTotalCount;
	}

	public void setVideoTotalCount(Integer videoTotalCount) {
		this.videoTotalCount = videoTotalCount;
	}

	public Integer getVideoPornCount() {
		return this.videoPornCount;
	}

	public void setVideoPornCount(Integer videoPornCount) {
		this.videoPornCount = videoPornCount;
	}

	public Integer getVideoTerrorismCount() {
		return this.videoTerrorismCount;
	}

	public void setVideoTerrorismCount(Integer videoTerrorismCount) {
		this.videoTerrorismCount = videoTerrorismCount;
	}

	public List<Bucket> getBucketList() {
		return this.bucketList;
	}

	public void setBucketList(List<Bucket> bucketList) {
		this.bucketList = bucketList;
	}

	public List<String> getSceneList() {
		return this.sceneList;
	}

	public void setSceneList(List<String> sceneList) {
		this.sceneList = sceneList;
	}

	public List<String> getResouceTypeList() {
		return this.resouceTypeList;
	}

	public void setResouceTypeList(List<String> resouceTypeList) {
		this.resouceTypeList = resouceTypeList;
	}

	public static class Bucket {

		private Boolean selected;

		private String bucket;

		private List<String> prefixes;

		public Boolean getSelected() {
			return this.selected;
		}

		public void setSelected(Boolean selected) {
			this.selected = selected;
		}

		public String getBucket() {
			return this.bucket;
		}

		public void setBucket(String bucket) {
			this.bucket = bucket;
		}

		public List<String> getPrefixes() {
			return this.prefixes;
		}

		public void setPrefixes(List<String> prefixes) {
			this.prefixes = prefixes;
		}
	}

	@Override
	public DescribeOssStockStatusResponse getInstance(UnmarshallerContext context) {
		return	DescribeOssStockStatusResponseUnmarshaller.unmarshall(this, context);
	}

	@Override
	public boolean checkShowJsonItemName() {
		return false;
	}
}

==> aliyun-java-sdk-green-3.6.5-sources.jar: com/aliyuncs/green/model/v20170823/DescribeOssStockStatusResponse.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.green.model.v20170823;

import java.util.List;
import com.aliyuncs.AcsResponse;
import com.aliyuncs.green.transform.v20170823.DescribeOssStockStatusResponseUnmarshaller;
import com.aliyuncs.transform.UnmarshallerContext;

/**
 * @author auto create
 * @version 
 */
public class DescribeOssStockStatusResponse extends AcsResponse {

	private String requestId;

	private Integer stockStatus;

	private String finishedTime;

	private Integer imageTotalCount;

	private Integer imagePornCount;

	private Integer imageTerrorismCount;

	private Integer imageAdCount;

	private Integer imageLiveCount;

	private Integer videoTotalCount;

	private Integer videoPornCount;

	private Integer videoTerrorismCount;

	private Integer videoAdCount;

	private Integer videoLiveCount;

	private Integer videoVoiceAntispamCount;

	private Integer audioTotalCount;

	private Integer audioAntispamCount;

	private List<Bucket> bucketList;

	private List<String> sceneList;

	private List<String> resouceTypeList;

	public String getRequestId() {
		return this.requestId;
	}

	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	public Integer getStockStatus() {
		return this.stockStatus;
	}

	public void setStockStatus(Integer stockStatus) {
		this.stockStatus = stockStatus;
	}

	public String getFinishedTime() {
		return this.finishedTime;
	}

	public void setFinishedTime(String finishedTime) {
		this.finishedTime = finishedTime;
	}

	public Integer getImageTotalCount() {
		return this.imageTotalCount;
	}

	public void setImageTotalCount(Integer imageTotalCount) {
		this.imageTotalCount = imageTotalCount;
	}

	public Integer getImagePornCount() {
		return this.imagePornCount;
	}

	public void setImagePornCount(Integer imagePornCount) {
		this.imagePornCount = imagePornCount;
	}

	public Integer getImageTerrorismCount() {
		return this.imageTerrorismCount;
	}

	public void setImageTerrorismCount(Integer imageTerrorismCount) {
		this.imageTerrorismCount = imageTerrorismCount;
	}

	public Integer getImageAdCount() {
		return this.imageAdCount;
	}

	public void setImageAdCount(Integer imageAdCount) {
		this.imageAdCount = imageAdCount;
	}

	public Integer getImageLiveCount() {
		return this.imageLiveCount;
	}

	public void setImageLiveCount(Integer imageLiveCount) {
		this.imageLiveCount = imageLiveCount;
	}

	public Integer getVideoTotalCount() {
		return this.videoTotalCount;
	}

	public void setVideoTotalCount(Integer videoTotalCount) {
		this.videoTotalCount = videoTotalCount;
	}

	public Integer getVideoPornCount() {
		return this.videoPornCount;
	}

	public void setVideoPornCount(Integer videoPornCount) {
		this.videoPornCount = videoPornCount;
	}

	public Integer getVideoTerrorismCount() {
		return this.videoTerrorismCount;
	}

	public void setVideoTerrorismCount(Integer videoTerrorismCount) {
		this.videoTerrorismCount = videoTerrorismCount;
	}

	public Integer getVideoAdCount() {
		return this.videoAdCount;
	}

	public void setVideoAdCount(Integer videoAdCount) {
		this.videoAdCount = videoAdCount;
	}

	public Integer getVideoLiveCount() {
		return this.videoLiveCount;
	}

	public void setVideoLiveCount(Integer videoLiveCount) {
		this.videoLiveCount = videoLiveCount;
	}

	public Integer getVideoVoiceAntispamCount() {
		return this.videoVoiceAntispamCount;
	}

	public void setVideoVoiceAntispamCount(Integer videoVoiceAntispamCount) {
		this.videoVoiceAntispamCount = videoVoiceAntispamCount;
	}

	public Integer getAudioTotalCount() {
		return this.audioTotalCount;
	}

	public void setAudioTotalCount(Integer audioTotalCount) {
		this.audioTotalCount = audioTotalCount;
	}

	public Integer getAudioAntispamCount() {
		return this.audioAntispamCount;
	}

	public void setAudioAntispamCount(Integer audioAntispamCount) {
		this.audioAntispamCount = audioAntispamCount;
	}

	public List<Bucket> getBucketList() {
		return this.bucketList;
	}

	public void setBucketList(List<Bucket> bucketList) {
		this.bucketList = bucketList;
	}

	public List<String> getSceneList() {
		return this.sceneList;
	}

	public void setSceneList(List<String> sceneList) {
		this.sceneList = sceneList;
	}

	public List<String> getResouceTypeList() {
		return this.resouceTypeList;
	}

	public void setResouceTypeList(List<String> resouceTypeList) {
		this.resouceTypeList = resouceTypeList;
	}

	public static class Bucket {

		private Boolean selected;

		private String bucket;

		private List<String> prefixes;

		public Boolean getSelected() {
			return this.selected;
		}

		public void setSelected(Boolean selected) {
			this.selected = selected;
		}

		public String getBucket() {
			return this.bucket;
		}

		public void setBucket(String bucket) {
			this.bucket = bucket;
		}

		public List<String> getPrefixes() {
			return this.prefixes;
		}

		public void setPrefixes(List<String> prefixes) {
			this.prefixes = prefixes;
		}
	}

	@Override
	public DescribeOssStockStatusResponse getInstance(UnmarshallerContext context) {
		return	DescribeOssStockStatusResponseUnmarshaller.unmarshall(this, context);
	}

	@Override
	public boolean checkShowJsonItemName() {
		return false;
	}
}
